@@ -1,5 +1,7 @@
 package # hide from PAUSE
         Win32::Console;
+use strict;
+use warnings;
 
 sub new {}
 
