@@ -1,8 +1,9 @@
 package # hide from PAUSE
         Win32::EventLog;
 use strict;
+use warnings;
 use Carp;
-require Exporter;
+use Exporter ();
 
 {
     no strict;
@@ -525,7 +526,7 @@ SE<eacute>bastien Aperghis-Tramoni E<lt>sebastien@aperghis.netE<gt>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2007 SE<eacute>bastien Aperghis-Tramoni, All Rights Reserved.
+Copyright 2007, 2008 SE<eacute>bastien Aperghis-Tramoni, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
